pub struct DebugInfo {
pub brillig_locations: BTreeMap<BrilligFunctionId, BTreeMap<BrilligOpcodeLocation, CallStackId>>,
pub location_tree: LocationTree,
pub acir_locations: BTreeMap<AcirOpcodeLocation, CallStackId>,
pub variables: DebugVariables,
pub functions: DebugFunctions,
pub types: DebugTypes,
pub brillig_procedure_locs: BTreeMap<BrilligFunctionId, BTreeMap<ProcedureDebugId, (usize, usize)>>,
}Fields
brillig_locations: BTreeMap<BrilligFunctionId, BTreeMap<BrilligOpcodeLocation, CallStackId>>location_tree: LocationTreeacir_locations: BTreeMap<AcirOpcodeLocation, CallStackId>Map opcode index of an ACIR circuit into the source code location
variables: DebugVariablesfunctions: DebugFunctionstypes: DebugTypesbrillig_procedure_locs: BTreeMap<BrilligFunctionId, BTreeMap<ProcedureDebugId, (usize, usize)>>This a map per brillig function representing the range of opcodes where a procedure is activated.
Implementations
Sourceimpl DebugInfo
impl DebugInfo
pub fn new( brillig_locations: BTreeMap<BrilligFunctionId, BTreeMap<BrilligOpcodeLocation, CallStackId>>, location_map: BTreeMap<AcirOpcodeLocation, CallStackId>, location_tree: LocationTree, variables: DebugVariables, functions: DebugFunctions, types: DebugTypes, brillig_procedure_locs: BTreeMap<BrilligFunctionId, BTreeMap<ProcedureDebugId, (usize, usize)>>, ) -> Self
Sourcepub fn update_acir(&mut self, update_map: AcirTransformationMap)
pub fn update_acir(&mut self, update_map: AcirTransformationMap)
Updates the locations map when the Circuit is modified.
The OpcodeLocations are generated with the ACIR, but passing the ACIR through a transformation step
renders the old OpcodeLocations invalid. The AcirTransformationMap is able to map the old OpcodeLocation to the new ones.
Note: One old OpcodeLocation might have transformed into more than one new OpcodeLocation.
pub fn acir_opcode_location( &self, loc: &AcirOpcodeLocation, ) -> Option<Vec<Location>>
pub fn opcode_location(&self, loc: &OpcodeLocation) -> Option<Vec<Location>>